# Markdown

```{vb:function} Private Function getId(ByVal name As String, ByVal age As Integer) As Integer
:module: MD

かんたんなプライベート関数
その説明

:param name: 名前
:type name: String
:param age: 年齢
:type age: Integer
:returns: id
:rtype: Integer

ここに remarks を書く。
```

```{vb:function} Private Function id取得(ByVal name As String, ByVal age As Integer) As Integer
:module: MD

かんたんなプライベート関数

:param name: 名前
:type name: String
:param age: 年齢
:type age: Integer
:returns: id
:rtype: Integer

ここに remarks を書く。
```
